@@ -1,9 +1,5 @@
 //! This is just a sample of what FFI using this crate can look like.
 
-// Disable `improper_ctypes` warnings so that we don't lint about
-// `Option<OwnedFd>` appearing in an FFI signature. In the future rustc
-// would be modified to recognize this case.
-#![cfg_attr(rustc_attrs, allow(improper_ctypes))]
 #![cfg_attr(not(rustc_attrs), allow(unused_imports))]
 #![allow(missing_docs)]
 
@@ -21,7 +17,7 @@ use winapi::{
     um::minwinbase::{LPOVERLAPPED, LPSECURITY_ATTRIBUTES},
 };
 
-/// Declare a few FFI functions ourselves, to show off the FFI ergonomics.
+// Declare a few FFI functions ourselves, to show off the FFI ergonomics.
 #[cfg(all(rustc_attrs, any(unix, target_os = "wasi")))]
 extern "C" {
     pub fn open(pathname: *const c_char, flags: c_int, ...) -> Option<OwnedFd>;
@@ -38,7 +34,7 @@ pub use libc::{O_CLOEXEC, O_CREAT, O_RDONLY, O_RDWR, O_TRUNC, O_WRONLY};
 /// the return type for `CreateFileW`, since that function is defined to return
 /// [`INVALID_HANDLE_VALUE`] on error instead of null.
 #[cfg(windows)]
-extern "C" {
+extern "system" {
     pub fn CreateFileW(
         lpFileName: LPCWSTR,
         dwDesiredAccess: DWORD,
