@@ -3,9 +3,9 @@
 //! just a temporary measure.
 
 #[cfg(any(unix, target_os = "wasi"))]
-use crate::{AsFd, BorrowedFd, FromFd, IntoFd, OwnedFd};
+use crate::{AsFd, BorrowedFd, IntoFd, OwnedFd};
 #[cfg(windows)]
-use crate::{AsHandle, BorrowedHandle, FromHandle, IntoHandle, OwnedHandle};
+use crate::{AsHandle, BorrowedHandle, IntoHandle, OwnedHandle};
 #[cfg(unix)]
 use std::os::unix::io::{AsRawFd, FromRawFd, IntoRawFd};
 #[cfg(target_os = "wasi")]
@@ -17,7 +17,7 @@ use std::os::windows::io::{AsRawHandle, FromRawHandle, IntoRawHandle};
 impl AsFd for fs_err::File {
     #[inline]
     fn as_fd(&self) -> BorrowedFd<'_> {
-        unsafe { BorrowedFd::borrow_raw_fd(self.as_raw_fd()) }
+        unsafe { BorrowedFd::borrow_raw(self.as_raw_fd()) }
     }
 }
 
@@ -25,7 +25,7 @@ impl AsFd for fs_err::File {
 impl AsHandle for fs_err::File {
     #[inline]
     fn as_handle(&self) -> BorrowedHandle<'_> {
-        unsafe { BorrowedHandle::borrow_raw_handle(self.as_raw_handle()) }
+        unsafe { BorrowedHandle::borrow_raw(self.as_raw_handle()) }
     }
 }
 
@@ -44,19 +44,3 @@ impl IntoHandle for fs_err::File {
         unsafe { OwnedHandle::from_raw_handle(self.into_raw_handle()) }
     }
 }
-
-#[cfg(any(unix, target_os = "wasi"))]
-impl FromFd for fs_err::File {
-    #[inline]
-    fn from_fd(owned: OwnedFd) -> Self {
-        unsafe { Self::from_raw_fd(owned.into_raw_fd()) }
-    }
-}
-
-#[cfg(windows)]
-impl FromHandle for fs_err::File {
-    #[inline]
-    fn from_handle(owned: OwnedHandle) -> Self {
-        unsafe { Self::from_raw_handle(owned.into_raw_handle()) }
-    }
-}
